@@ -244,6 +244,44 @@ class Gallery(View):
             with open(f"{dir_base}/content/mysite/gallery/{public_name}/title-block.html", "w") as hugo_file:
                 pass
 
+            gallery_ejs = """
+```{=html}
+
+<div class="list grid" style="column-gap: 10px;">
+
+<% for (const tile of items) { %>
+  <div class="card border-2 rounded-3 g-col-12 g-col-sm-6 g-col-md-4 mb-2" <%= m
+etadataAttrs(tile) %>>
+   <div class="card-body">
+    <div class="card-header py-1 px-2 border-bottom border-1 ">
+        <small class="card-title"><%= tile.subtitle %></small>
+      <small class="inline-block text-right">
+        <a href="<%- tile.path %>" class="listing-title"><%= tile.title %></a>
+      </small>
+    </div>
+    <% if (tile.image) { %>
+      <a href="<%- tile.path %>">
+        <img src="<%- tile.thumbnail %>" alt="<%- tile.description %>" class="ca
+rd-img-top"/>
+    </a>
+    <% } else { %>
+        <span class="text-muted">No IIIF Image available yet</span>
+   <% } %>
+    <% if (tile.author ) { %>
+      </div>
+      <div class="card-footer">
+           <span class="text-center"> <%- tile.author %></span>
+   <% } %>
+      </div>
+  </div>
+<% } %>
+</div>
+
+```
+"""
+
+            with open(f"{dir_base}/content/mysite/map/{public_name}/gallery.ejs", "w") as resource_file:
+                resource_file.write(gallery_ejs)
 
             with open(f"{dir_base}/content/mysite/gallery/{public_name}/index.qmd", "w") as hugo_file:
                 hugo_file.write("---\n")
@@ -401,6 +439,47 @@ class Map(View):
                 hugo_file.write(f"type: {public_name}\n")
                 hugo_file.write("---\n")
 
+
+                map_ejs = """
+```{=html}
+<script src="https://unpkg.com/leaflet@1.8.0/dist/leaflet.js" integrity="sha512-
+BB3hKbKWOc9Ez/TAwyWxNXeoV9c1v6FIeYiBieIWkpLjauysF18NzgR1MBNBXf8/KABdlkX68nAhlwcD
+FLGPCQ==" crossorigin=""></script>
+<script src="leaflet.markercluster.js"></script>
+
+<div id="map" style="width: 90%; height: 800px;"></div>
+<script>
+
+	var map = L.map('map').setView([53.8167, -3.0370], 6);
+
+	var tiles = L.tileLayer('https://api.mapbox.com/styles/v1/{id}/tiles/{z}
+/{x}/{y}?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ
+3N3gifQ.rJcFIG214AriISLbB6B5aw', {
+		maxZoom: 18,
+		attribution: 'Map data &copy; <a href="https://www.openstreetmap
+.org/copyright">OpenStreetMap</a> contributors, ' +
+			'Imagery © <a href="https://www.mapbox.com/">Mapbox</a>'
+,
+		id: 'mapbox/streets-v11',
+		tileSize: 512,
+		zoomOffset: -1
+	}).addTo(map);
+
+        var markers = L.markerClusterGroup();
+<% for (const item of items) { %>
+	markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup(
+'<%= String(item.title).replace(/'/g, "\\'") %>'));
+<% } %>
+
+      map.addLayer(markers);
+
+</script>
+```
+"""
+
+            with open(f"{dir_base}/content/mysite/map/{public_name}/map.ejs", "w") as resource_file:
+                resource_file.write(map_ejs)
+
             with open(f"{dir_base}/content/mysite/map/{public_name}/index.qmd", "w") as hugo_file:
                 hugo_file.write("---\n")
                 hugo_file.write(f"title: \"Map\"\n")
